@@ -14,7 +14,10 @@ our @EXPORT_OK = qw(
                        wrapres
                );
 
-our $VERSION = '0.36'; # VERSION
+our $VERSION = '0.37'; # VERSION
+
+our @_c; # to store temporary celler() result
+our $_i; # temporary variable
 
 sub err {
 
@@ -60,10 +63,18 @@ sub err {
                     ref($prev->[3]{logs}[0]) eq 'HASH' &&
                         $prev->[3]{logs}[0]{stack_trace};
             $stack_trace = [];
-            my $i = 1;
-            while (my @c = CORE::caller($i)) {
-                push @$stack_trace, \@c;
-                $i++;
+            $_i = 1;
+            while (1) {
+                {
+                    package DB;
+                    @_c = CORE::caller($_i);
+                    if (@_c) {
+                        $_c[4] = [@DB::args];
+                    }
+                }
+                last unless @_c;
+                push @$stack_trace, [@_c];
+                $_i++;
             }
         }
         push @{ $meta->{logs} }, {
@@ -104,6 +115,7 @@ sub caller {
     return defined($n0) ? @r : $r[0];
 }
 
+# DEPRECATED since 2013-09-15: no longer documented and to remove later
 sub wrapres {
     my ($ores, $ires) = @_;
 
@@ -152,7 +164,7 @@ Perinci::Sub::Util - Helper when writing functions
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
